package com.jiuqi.util;

import java.sql.Time;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

public class DataConvert {
   public static final int ftString = 12;
   public static final int ftInteger = 4;
   public static final int ftBoolean = -7;
   public static final int ftFloat = 2;
   public static final int ftDate = 91;
   public static final int ftDateTime = 93;
   public static final String[] BoolTrueCaptions = new String[]{"是", "真", "True", "T", "1"};
   public static final String[] BoolFalseCaptions = new String[]{"否", "假", "False", "F", "0"};
   public static final SimpleDateFormat default_date_format = new SimpleDateFormat("yyyy-MM-dd");
   public static final SimpleDateFormat default_time_format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

   public static int stringToInt(String data) {
      try {
         return data != null && !data.equals("") ? Integer.parseInt(data) : 0;
      } catch (NumberFormatException var1) {
         return 0;
      }
   }

   public static boolean stringToBool(String str) {
      if (str == null) {
         return false;
      } else {
         for(int i = 0; i < BoolTrueCaptions.length; ++i) {
            if (str.equalsIgnoreCase(BoolTrueCaptions[i])) {
               return true;
            }
         }

         return false;
      }
   }

   public static Object stringToValue(String data, int zbtype) {
      if (data == null) {
         return null;
      } else {
         try {
            switch (zbtype) {
               case -7:
                  return stringToBool(data) ? Boolean.TRUE : Boolean.FALSE;
               case 2:
                  return data.equals("") ? null : Double.valueOf(data);
               case 4:
                  try {
                     return data.equals("") ? null : Integer.valueOf(data);
                  } catch (NumberFormatException var2) {
                     return new Integer(Double.valueOf(data).intValue());
                  }
               case 12:
                  return data;
               case 91:
                  return default_date_format.parse(data);
               case 93:
                  return new Timestamp(default_time_format.parse(data).getTime());
            }
         } catch (NumberFormatException var3) {
         } catch (ParseException var4) {
         }

         return null;
      }
   }

   public static String valueToString(int value) {
      return String.valueOf(value);
   }

   public static String valueToString(Object value) {
      return valueToString(value, false);
   }

   public static String valueToString(Object value, boolean quoteString) {
      if (value == null) {
         return null;
      } else if (value instanceof Double) {
         return value.toString();
      } else if (value instanceof Integer) {
         return value.toString();
      } else if (value instanceof Boolean) {
         return (Boolean)value ? "1" : "0";
      } else if (value instanceof String) {
         return !quoteString ? (String)value : JqLib.quoteString((String)value);
      } else if (value instanceof Time) {
         return default_time_format.format((Time)value);
      } else if (value instanceof Timestamp) {
         return default_time_format.format((Timestamp)value);
      } else if (value instanceof Date) {
         return default_date_format.format((Date)value);
      } else {
         return value instanceof Calendar ? default_date_format.format(((Calendar)value).getTime()) : value.toString();
      }
   }

   public static String valuesToString(Object value, boolean quoteString) {
      if (value == null) {
         return null;
      } else if (!(value instanceof Object[])) {
         return valueToString(value, quoteString);
      } else {
         Object[] values = (Object[])value;
         String result = "";

         for(int i = 0; i < values.length; ++i) {
            result = result + valueToString(values[i], quoteString) + ';';
         }

         return result;
      }
   }
}
